# -*- coding: utf-8 -*-
"""
This module contains code for the class Dof_Ptv and its related components.
"""


__author__ = "Martin Sandve Alnes"
__date__   = "2008-09-03"
__copyright__ = "(C) 2008 Martin Sandve Alnes and Simula Resarch Laboratory"
__license__  = "GNU GPL Version 2, or (at your option) any later version"

from sfc.dofcode.Ptv import Ptv
from sfc.dofcode.DofT import DofT
from sfc.dofcode.Dof_Ptv import Dof_Ptv

def gen_utility_code(hfilename):
    name = hfilename.split(".")[0]
    if name == "Ptv":
       return name, Ptv.header, Ptv.implementation
    if name == "DofT":
       return name, DofT.header, DofT.implementation
    if name == "Dof_Ptv":
       return name, Dof_Ptv.header, Dof_Ptv.implementation
    raise RuntimeError("Unknown utility '%s'." % hfilename)

